[![PyPI version](https://badge.fury.io/py/my-movie-database.svg)](https://badge.fury.io/py/my-movie-database)

# my-movie-database

A command line tool to keep track of the movies you watched. Installable via pip. Uses SqlAlchemy. Built for Linux

## Medium

For a detailed guide on using this application refer to the Medium article at https://medium.com/@kumuthu53/my-movie-database-9298707293fd.

## How to Install

Use pip to install. Requires Python>=3.10.

`pip install my-movie-database`

## How to Run

To run, simply type `my-movie-database` in your terminal.
